summaryrefslogtreecommitdiffstats
path: root/kig/misc/object_hierarchy.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/misc/object_hierarchy.h')
-rw-r--r--kig/misc/object_hierarchy.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kig/misc/object_hierarchy.h b/kig/misc/object_hierarchy.h
index 60df8a59..cda2615f 100644
--- a/kig/misc/object_hierarchy.h
+++ b/kig/misc/object_hierarchy.h
@@ -73,22 +73,22 @@ public:
std::vector<ObjectImp*> calc( const Args& a, const KigDocument& doc ) const;
/**
* saves the ObjectHierarchy data in children xml tags of \p parent ..
*/
- void serialize( TQDomElement& parent, TQDomDocument& doc ) const;
+ void serialize( TQDomElement& tqparent, TQDomDocument& doc ) const;
/**
* Deserialize the ObjectHierarchy data from the xml element \p parent ..
* Since this operation can fail for some reasons, we provide it as a
* static to return 0 in case of error.
*/
- static ObjectHierarchy* buildSafeObjectHierarchy( const TQDomElement& parent, TQString& error );
-// ObjectHierarchy( const TQDomElement& parent );
+ static ObjectHierarchy* buildSafeObjectHierarchy( const TQDomElement& tqparent, TQString& error );
+// ObjectHierarchy( const TQDomElement& tqparent );
/**
* build a set of objects that interdepend according to this
* ObjectHierarchy.. Only the result objects are returned. Helper
* objects that connect the given objects with the returned objects,
- * can only be found by following the returned objects' parents()
+ * can only be found by following the returned objects' tqparents()
* methods..
*/
std::vector<ObjectCalcer*> buildObjects( const std::vector<ObjectCalcer*>& os, const KigDocument& ) const;
@@ -73,22 +73,22 @@ public:
std::vector<ObjectImp*> calc( const Args& a, const KigDocument& doc ) const;
/**
- * saves the ObjectHierarchy data in children xml tags of \p parent ..
+ * saves the ObjectHierarchy data in tqchildren xml tags of \p tqparent ..
*/
@@ -73,22 +73,22 @@ public:
/**
- * Deserialize the ObjectHierarchy data from the xml element \p parent ..
+ * Deserialize the ObjectHierarchy data from the xml element \p tqparent ..
* Since this operation can fail for some reasons, we provide it as a
* static to return 0 in case of error.